# Welcome to the SysE Python Package!

SysE (/Sis'y/) is a Python library for Systems Engineering.

SysE covers common Industrial & Systems Engineering methods such as:

Some use cases include:

To get started, check out the docs for further information, including how to install SysE and common use cases.

**Links:**
* **Documentation:** [SysE Docs](https://syse.readthedocs.io/en/latest/)
* **Repository:** [SysE Repo](https://github.com/Apex-Engineering-Management/SysE)

**Note:**

This project is under active development.